@@ -507,12 +507,12 @@ SCIP_DECL_EVENTEXEC(processVarEvent)
 
    if( SCIPeventGetType(event) & SCIP_EVENTTYPE_GLBCHANGED )
    {
-      SCIP_CALL( SCIPchgVarLbGlobal(heurdata->subscip, subvar, SCIPvarGetLbGlobal(var)) );
+      SCIP_CALL( SCIPchgVarLbGlobal(heurdata->subscip, subvar, SCIPeventGetNewbound(event)) );
    }
 
    if( SCIPeventGetType(event) & SCIP_EVENTTYPE_GUBCHANGED )
    {
-      SCIP_CALL( SCIPchgVarUbGlobal(heurdata->subscip, subvar, SCIPvarGetUbGlobal(var)) );
+      SCIP_CALL( SCIPchgVarUbGlobal(heurdata->subscip, subvar, SCIPeventGetNewbound(event)) );
    }
 
    return SCIP_OKAY;
@@ -592,7 +592,7 @@ SCIP_RETCODE processNLPSol(
    SCIP_HEUR*            authorheur,         /**< the heuristic that should be the author of solution, if any */
    SCIP_RESULT*          result,             /**< buffer to store result FOUNDSOL if a solution has been found and accepted */
    SCIP_SOL*             resultsol           /**< a solution where to store found solution values, if any, or NULL if to try adding to SCIP */
-)
+   )
 {
    SCIP_HEURDATA* heurdata;
 
