@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright 2002-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -667,6 +667,11 @@ void SCIPsyncdataSetStatus(
          syncdata->winner = solverid;
       }
    }
+   else if( syncdata->winner < 0 )
+   {
+      syncdata->status = status;
+      syncdata->winner = solverid;
+   }
 }
 
 /** adds memory used to the synchronization data */
