@@ -270,15 +270,14 @@ SCIP_RETCODE createVariableNodes(
    SCIP*                 scip,               /**< SCIP instance */
    bliss::Graph*         G,                  /**< Graph to be constructed */
    SYM_MATRIXDATA*       matrixdata,         /**< data for MIP matrix (also contains the relevant variables) */
-   int&                  nnodes,             /**< buffer to store number of nodes in graph */
-   const int&            nedges,             /**< buffer to store number of edges in graph */
-   int&                  nusedcolors         /**< buffer to store number of used colors */
+   int&                  nnodes,             /**< returns number of nodes in graph */
+   int&                  nusedcolors         /**< returns number of used colors */
    )
 {
    assert( scip != NULL );
    assert( G != NULL );
+   assert( matrixdata != NULL );
    assert( nnodes == 0 );
-   assert( nedges == 0 );
    assert( nusedcolors == 0 );
    SCIPdebugMsg(scip, "Creating graph with colored nodes for variables.\n");
 
@@ -322,9 +321,9 @@ SCIP_RETCODE fillGraphByLinearConss(
    SCIP*                 scip,               /**< SCIP instance */
    bliss::Graph*         G,                  /**< Graph to be constructed */
    SYM_MATRIXDATA*       matrixdata,         /**< data for MIP matrix */
-   int&                  nnodes,             /**< buffer to store number of nodes in graph */
-   int&                  nedges,             /**< buffer to store number of edges in graph */
-   int&                  nusedcolors,        /**< buffer to store number of used colors */
+   int&                  nnodes,             /**< number of nodes in graph */
+   int&                  nedges,             /**< number of edges in graph */
+   int&                  nusedcolors,        /**< number of used colors */
    SCIP_Bool&            success             /**< whether the construction was successful */
    )
 {
@@ -431,13 +430,17 @@ SCIP_RETCODE fillGraphByLinearConss(
             varrhsidx = matrixdata->matvaridx[idx];
          assert( 0 <= varrhsidx && varrhsidx < ninternodes );
 
+         SCIP_Bool newinternode = FALSE;
          if ( internodes[varrhsidx] < firstcolornodenumber )
          {
             internodes[varrhsidx] = (int) G->add_vertex((unsigned) (nusedcolors + color));
             ++nnodes;
+            newinternode = TRUE;
          }
-         assert( internodes[varrhsidx] >= matrixdata->npermvars + matrixdata->nrhscoef );
-         assert( internodes[varrhsidx] >= firstcolornodenumber );
+         int internode = internodes[varrhsidx];
+         assert( internode >= matrixdata->npermvars + matrixdata->nrhscoef );
+         assert( internode >= firstcolornodenumber );
+         assert( internode < nnodes );
 
          /* determine whether graph would be too large for bliss (can only handle int) */
          if ( nnodes >= INT_MAX/2 )
@@ -446,9 +449,26 @@ SCIP_RETCODE fillGraphByLinearConss(
             break;
          }
 
-         G->add_edge((unsigned) varnode, (unsigned) internodes[varrhsidx]);
-         G->add_edge((unsigned) rhsnode, (unsigned) internodes[varrhsidx]);
-         nedges += 2;
+         if ( groupByConstraints )
+         {
+            if ( newinternode )
+            {
+               G->add_edge((unsigned) rhsnode, (unsigned) internode);
+               ++nedges;
+            }
+            G->add_edge((unsigned) varnode, (unsigned) internode);
+            ++nedges;
+         }
+         else
+         {
+            if ( newinternode )
+            {
+               G->add_edge((unsigned) varnode, (unsigned) internode);
+               ++nedges;
+            }
+            G->add_edge((unsigned) rhsnode, (unsigned) internode);
+            ++nedges;
+         }
       }
    }
 
@@ -484,9 +504,9 @@ SCIP_RETCODE fillGraphByNonlinearConss(
    SCIP*                 scip,               /**< SCIP instance */
    bliss::Graph*         G,                  /**< Graph to be constructed */
    SYM_EXPRDATA*         exprdata,           /**< data for nonlinear constraints */
-   int&                  nnodes,             /**< buffer to store number of nodes in graph */
-   int&                  nedges,             /**< buffer to store number of edges in graph */
-   int&                  nusedcolors,        /**< number of used colors ind the graph so far */
+   int&                  nnodes,             /**< number of nodes in graph */
+   int&                  nedges,             /**< number of edges in graph */
+   int&                  nusedcolors,        /**< number of colors in the graph so far */
    SCIP_Bool&            success             /**< whether the construction was successful */
    )
 {
@@ -500,6 +520,9 @@ SCIP_RETCODE fillGraphByNonlinearConss(
    SYM_RHSTYPE* uniquerhsarray = NULL;
    SCIP_CONSHDLR* conshdlr;
    SCIP_CONS** conss;
+   SCIP_VAR** vars = NULL;
+   SCIP_Real* vals = NULL;
+   int nvars;
    int nconss;
    int nuniqueops = 0;
    int nuniqueconsts = 0;
@@ -549,6 +572,9 @@ SCIP_RETCODE fillGraphByNonlinearConss(
    SCIP_CALL( SCIPallocBlockMemoryArray(scip, &sumcoefarray, coefarraysize) );
    SCIP_CALL( SCIPallocBlockMemoryArray(scip, &uniquerhsarray, rhsarraysize) );
 
+   /* get number of variables */
+   nvars = SCIPgetNVars(scip);
+
    SCIP_EXPRITER* it;
    SCIP_CALL( SCIPcreateExpriter(scip, &it) );
 
@@ -567,9 +593,9 @@ SCIP_RETCODE fillGraphByNonlinearConss(
 
       for (SCIP_EXPR* expr = SCIPexpriterGetCurrent(it); !SCIPexpriterIsEnd(it); expr = SCIPexpriterGetNext(it)) /*lint !e441*/ /*lint !e440*/
       {
+         /* upon entering an expression, check its type and add nodes and edges if neccessary */
          switch( SCIPexpriterGetStageDFS(it) )
          {
-            /* upon entering an expression, check its type and add nodes and edges if neccessary */
             case SCIP_EXPRITER_ENTEREXPR:
             {
                int node = -1;
@@ -592,29 +618,23 @@ SCIP_RETCODE fillGraphByNonlinearConss(
                   }
                   else
                   {
-                     SCIP_VAR** vars = NULL;
-                     SCIP_Real* vals = NULL;
-                     SCIP_Real constant = 0;
-                     int varsize = 1;
+                     SCIP_Real constant = 0.0;
+                     int varssize;
                      int requiredsize;
                      int k;
 
-                     SCIP_CALL( SCIPallocBufferArray(scip, &vars, varsize) );
-                     SCIP_CALL( SCIPallocBufferArray(scip, &vals, varsize) );
+                     if ( vars == NULL )
+                     {
+                        SCIP_CALL( SCIPallocBlockMemoryArray(scip, &vars, nvars) );
+                        SCIP_CALL( SCIPallocBlockMemoryArray(scip, &vals, nvars) );
+                     }
+                     assert( vars != NULL && vals != NULL );
 
                      vars[0] = var;
                      vals[0] = 1.0;
 
-                     SCIP_CALL( SCIPgetProbvarLinearSum(scip, vars, vals, &varsize, varsize, &constant, &requiredsize, TRUE) );
-
-                     if ( requiredsize > varsize )
-                     {
-                        SCIP_CALL( SCIPreallocBufferArray(scip, &vars, requiredsize) );
-                        SCIP_CALL( SCIPreallocBufferArray(scip, &vals, requiredsize) );
-
-                        SCIP_CALL( SCIPgetProbvarLinearSum(scip, vars, vals, &varsize, requiredsize, &constant, &requiredsize, TRUE) );
-                        assert( requiredsize <= varsize );
-                     }
+                     SCIP_CALL( SCIPgetProbvarLinearSum(scip, vars, vals, &varssize, nvars, &constant, &requiredsize, TRUE) );
+                     assert( requiredsize <= nvars );
 
                      parentnode = visitednodes[visitednodes.size() - 1];
                      assert( parentnode < (int) G->get_nof_vertices() );
@@ -702,9 +722,6 @@ SCIP_RETCODE fillGraphByNonlinearConss(
                         ++nedges;
                      }
 
-                     SCIPfreeBufferArray(scip, &vals);
-                     SCIPfreeBufferArray(scip, &vars);
-
                      /* add a filler node since it will be removed in the next iteration anyway */
                      visitednodes.push_back(nnodes);
                      ischildofsum.push_back(FALSE);
@@ -942,6 +959,9 @@ SCIP_RETCODE fillGraphByNonlinearConss(
    }
 
    /* free everything */
+   SCIPfreeBlockMemoryArrayNull(scip, &vals, nvars);
+   SCIPfreeBlockMemoryArrayNull(scip, &vars, nvars);
+
    SCIPfreeExpriter(&it);
    SCIPfreeBlockMemoryArrayNull(scip, &uniquerhsarray, rhsarraysize);
    SCIPfreeBlockMemoryArrayNull(scip, &sumcoefarray, coefarraysize);
@@ -961,23 +981,21 @@ SCIP_Bool SYMcanComputeSymmetry(void)
    return TRUE;
 }
 
-char*
-initStaticBlissName( );
-
-static char* blissname = initStaticBlissName();
-
+/** return name of external program used to compute generators */
 char*
 initStaticBlissName( )
 {
-   blissname = new char[100];
+   char* name = new char[100];
 #ifdef BLISS_PATCH_PRESENT
-   (void) SCIPsnprintf(blissname, 100, "bliss %sp", bliss::version);
+   (void) SCIPsnprintf(name, 100, "bliss %sp", bliss::version);
 #else
-   (void) SCIPsnprintf(blissname, 100, "bliss %s", bliss::version);
+   (void) SCIPsnprintf(name, 100, "bliss %s", bliss::version);
 #endif
-   return blissname;
+   return name;
 }
 
+/* static name for bliss */
+static char* blissname = initStaticBlissName();
 
 /** return name of external program used to compute generators */
 const char* SYMsymmetryGetName(void)
@@ -988,7 +1006,19 @@ const char* SYMsymmetryGetName(void)
 /** return description of external program used to compute generators */
 const char* SYMsymmetryGetDesc(void)
 {
-   return "Computing Graph Automorphism Groups by T. Junttila and P. Kaski (www.tcs.hut.fi/Software/bliss/)";
+   return "Computing Graph Automorphism Groups by T. Junttila and P. Kaski (https://users.aalto.fi/~tjunttil/bliss/)";
+}
+
+/** return name of additional external program used for computing symmetries */
+const char* SYMsymmetryGetAddName(void)
+{
+   return NULL;
+}
+
+/** return description of additional external program used to compute symmetries */
+const char* SYMsymmetryGetAddDesc(void)
+{
+   return NULL;
 }
 
 /** compute generators of symmetry group */
@@ -1000,9 +1030,12 @@ SCIP_RETCODE SYMcomputeSymmetryGenerators(
    int*                  nperms,             /**< pointer to store number of permutations */
    int*                  nmaxperms,          /**< pointer to store maximal number of permutations (needed for freeing storage) */
    int***                perms,              /**< pointer to store permutation generators as (nperms x npermvars) matrix */
-   SCIP_Real*            log10groupsize      /**< pointer to store size of group */
+   SCIP_Real*            log10groupsize,     /**< pointer to store size of group */
+   SCIP_Real*            symcodetime         /**< pointer to store the time for symmetry code */
    )
 {
+   SCIP_Real oldtime;
+
    assert( scip != NULL );
    assert( matrixdata != NULL );
    assert( exprdata != NULL );
@@ -1011,12 +1044,14 @@ SCIP_RETCODE SYMcomputeSymmetryGenerators(
    assert( perms != NULL );
    assert( log10groupsize != NULL );
    assert( maxgenerators >= 0 );
+   assert( symcodetime != NULL );
 
    /* init */
    *nperms = 0;
    *nmaxperms = 0;
    *perms = NULL;
    *log10groupsize = 0;
+   *symcodetime = 0.0;
 
    int nnodes = 0;
    int nedges = 0;
@@ -1027,7 +1062,7 @@ SCIP_RETCODE SYMcomputeSymmetryGenerators(
    bliss::Graph G(0);
 
    /* create nodes corresponding to variables */
-   SCIP_CALL( createVariableNodes(scip, &G, matrixdata, nnodes, nedges, nusedcolors) );
+   SCIP_CALL( createVariableNodes(scip, &G, matrixdata, nnodes, nusedcolors) );
 
    assert( nnodes == matrixdata->npermvars );
    assert( nusedcolors == matrixdata->nuniquevars );
@@ -1054,6 +1089,17 @@ SCIP_RETCODE SYMcomputeSymmetryGenerators(
    G.write_dot("debug.dot");
 #endif
 
+#if SCIP_DISABLED_CODE
+   char filename[SCIP_MAXSTRLEN];
+   (void) SCIPsnprintf(filename, SCIP_MAXSTRLEN, "%s.dimacs", SCIPgetProbName(scip));
+   FILE* fp = fopen(filename, "w");
+   if ( fp )
+   {
+      G.write_dimacs(fp);
+      fclose(fp);
+   }
+#endif
+
    SCIPdebugMsg(scip, "Symmetry detection graph has %u nodes.\n", G.get_nof_vertices());
 
    /* compute automorphisms */
@@ -1078,6 +1124,7 @@ SCIP_RETCODE SYMcomputeSymmetryGenerators(
    G.set_search_limits(0, (unsigned) maxgenerators);
 #endif
 
+   oldtime = SCIPgetSolvingTime(scip);
 #if BLISS_VERSION_MAJOR >= 1 || BLISS_VERSION_MINOR >= 76
    /* lambda function to have access to data and pass it to the blisshook above */
    auto reportglue = [&](unsigned int n, const unsigned int* aut) {
@@ -1095,7 +1142,7 @@ SCIP_RETCODE SYMcomputeSymmetryGenerators(
    /* start search */
    G.find_automorphisms(stats, blisshook, (void*) &data);
 #endif
-
+   *symcodetime = SCIPgetSolvingTime(scip) - oldtime;
 
 #ifdef SCIP_OUTPUT
    (void) stats.print(stdout);
