@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright 2002-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -30,8 +30,6 @@
 
 /*---+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8----+----9----+----0----+----1----+----2*/
 
-#include <libgen.h>
-
 #include "scip/scipdefplugins.h"
 #include "include/scip_test.h"
 
@@ -46,9 +44,7 @@ Test(readers, pip)
    char filename[SCIP_MAXSTRLEN];
 
    /* get file to read: test.mps that lives in the same directory as this file */
-   (void)SCIPsnprintf(filename, SCIP_MAXSTRLEN, "%s", __FILE__);
-   dirname(filename);
-   strcat(filename, "/test.pip");
+   TESTsetTestfilename(filename, __FILE__, "test.pip");
    printf("Reading %s\n", filename);
 
    SCIP_CALL( SCIPcreate(&scip) );
@@ -171,9 +167,7 @@ Test(readers, mps1)
    char filename[SCIP_MAXSTRLEN];
 
    /* get file to read: test.mps that lives in the same directory as this file */
-   (void)SCIPsnprintf(filename, SCIP_MAXSTRLEN, "%s", __FILE__);
-   dirname(filename);
-   strcat(filename, "/test.mps");
+   TESTsetTestfilename(filename, __FILE__, "test.mps");
    printf("Reading %s\n", filename);
 
    SCIP_CALL( SCIPcreate(&scip) );
@@ -248,9 +242,7 @@ Test(readers, zimpl)
    char filename[SCIP_MAXSTRLEN];
 
    /* get file to read: test.zpl that lives in the same directory as this file */
-   (void)SCIPsnprintf(filename, SCIP_MAXSTRLEN, "%s", __FILE__);
-   dirname(filename);
-   strcat(filename, "/test.zpl");
+   TESTsetTestfilename(filename, __FILE__, "test.zpl");
    printf("Reading %s\n", filename);
 
    SCIP_CALL( SCIPcreate(&scip) );
