@@ -1082,8 +1082,6 @@ Test(change, testlpiwritereadlpmethods)
    SCIP_Real activity2[2];
    SCIP_Real redcost2[2];
    SCIP_OBJSEN sense;
-   FILE* file;
-   FILE* file2;
 
    /* 2x2 problem */
    cr_assume( initProb(5, &ncols, &nrows, &nnonz, &sense) );
@@ -1107,12 +1105,22 @@ Test(change, testlpiwritereadlpmethods)
    SCIP_CALL( SCIPlpiWriteLP(lpi, "lpi_change_test_problem2.lp") );
    SCIP_CALL( SCIPlpiClear(lpi) );
 
-   file = fopen("lpi_change_test_problem.lp", "r");
-   file2 = fopen("lpi_change_test_problem2.lp", "r");
-   cr_assert_file_contents_eq(file, file2);
+   /* skip comparison of file content if LP solver is Xpress
+    * Xpress writes a timestamp to the .lp file, which makes a simple check for
+    * file content to be equal not reliable
+    */
+   if( strncmp(SCIPlpiGetSolverName(), "Xpress", 6) != 0 )
+   {
+      FILE* file;
+      FILE* file2;
 
-   fclose(file);
-   fclose(file2);
+      file = fopen("lpi_change_test_problem.lp", "r");
+      file2 = fopen("lpi_change_test_problem2.lp", "r");
+      cr_assert_file_contents_eq(file, file2);
+
+      fclose(file);
+      fclose(file2);
+   }
 
    remove("lpi_change_test_problem.lp");
    remove("lpi_change_test_problem2.lp");
